@@ -214,29 +214,21 @@ class Checker:
 
         self.print_logo()
         input(f"[{self.color}+{RESET}] {self.color}-{RESET} Press ENTER to start... ")
+        default_threads = threading.active_count()
         self.start_threads()
 
-        q = queue.Queue()
         for line in combo:
-            q.put_nowait(line)
+            try:
+                if self.proxy:
+                    proxy = self.get_proxy()
+                else:
+                    proxy = None
+                email, password = line.split(":")
+                thread = threading.Thread(target=check, args=(email, password, proxy))
+                thread.start()
+                if threading.active_count() == thread_count + default_threads:
+                    thread.join()
+            except IndexError:
+                pass
 
-        for _ in range(thread_count):
-            if self.proxy:
-                proxy = self.get_proxy()
-            else:
-                proxy = None
-            threading.Thread(target=self.worker, args=(check, q, proxy)).start()
-
-        '''
-        Your check function must have 3 parameters: email, password and proxy.
-        Whether you use proxies or not the parameter must be present.
-        If you don't use proxies your parameter will have a None type.
-        '''
-
-        q.join()
-        self.cui_thread_status = False
-        for thread in self.threads:
-            thread.join()
-        time.sleep(5)
-        self.print_logo()
-        print(f"[{self.color}+{RESET}] {self.color}-{RESET} Done, you can now close the window...")
+        input()
